@@ -425,8 +425,8 @@ class COCOeval:
         T = len(p.iouThrs)
         G = len(gt)
         D = len(dt)
-        gtm = np.ones((T, G), dtype=int) * -1
-        dtm = np.ones((T, D), dtype=int) * -1
+        gtm = np.ones((T, G), dtype=np.int64) * -1
+        dtm = np.ones((T, D), dtype=np.int64) * -1
         gtIg = np.array([g['_ignore'] for g in gt])
         dtIg = np.zeros((T,D))
         if len(ious):
@@ -535,8 +535,8 @@ class COCOeval:
                     # https://github.com/cocodataset/cocoapi/pull/332/
                     tps = np.logical_and(dtm >= 0, np.logical_not(dtIg))
                     fps = np.logical_and(dtm < 0, np.logical_not(dtIg))
-                    tp_sum = np.cumsum(tps, axis=1).astype(dtype=np.float)
-                    fp_sum = np.cumsum(fps, axis=1).astype(dtype=np.float)
+                    tp_sum = np.cumsum(tps, axis=1).astype(dtype=np.float64)
+                    fp_sum = np.cumsum(fps, axis=1).astype(dtype=np.float64)
                     for t, (tp, fp) in enumerate(zip(tp_sum, fp_sum)):
                         tp = np.array(tp)
                         fp = np.array(fp)
